**Example 1: test**



Input: 

```
tccli dlc SwitchDataEngine --cli-unfold-argument  \
    --DataEngineName test \
    --StartStandbyCluster False
```

Output: 
```
{
    "Response": {
        "RequestId": "2f67771a-a384-4b4e-86a5-146d8829ae2d"
    }
}
```

